Package: Compind
Type: Package
Title: Composite Indicators Functions
Version: 3.1
Date: 2024-03-25
Author: Francesco Vidoli, Elisa Fusco
Maintainer: Francesco Vidoli <fvidoli@gmail.com>
Description: A collection of functions to calculate Composite Indicators methods, focusing, in particular, on the normalisation and weighting-aggregation steps, as described in OECD Handbook on constructing composite indicators: methodology and user guide <https://www.oecd-ilibrary.org/economics/handbook-on-constructing-composite-indicators-methodology-and-user-guide_9789264043466-en>, 'Vidoli' and 'Fusco' and 'Mazziotta' <doi:10.1007/s11205-014-0710-y>, 'Mazziotta' and 'Pareto' (2016) <doi:10.1007/s11205-015-0998-2>, 'Van Puyenbroeck and 'Rogge' <doi:10.1016/j.ejor.2016.07.038> and other authors.
Depends: R (>= 3.5.0), Benchmarking, psych, boot, lpSolve, spdep
Imports: Hmisc, MASS, GPArotation, nonparaeff, smaa, np, FactoMineR,
        GWmodel, sp, Rcompadre
License: GPL-3
Suggests: R.rsp
VignetteBuilder: R.rsp
NeedsCompilation: no
Packaged: 2024-03-25 12:20:40 UTC; Fra
Repository: CRAN
Date/Publication: 2024-03-25 12:42:47 UTC
Built: R 4.2.3; ; 2024-03-25 16:16:08 UTC; unix
