Package: Compind
Type: Package
Title: Composite Indicators Functions
Version: 3.6
Date: 2026-7-10
Authors@R: c(person(given = "Francesco",
                        family = "Vidoli",
                        role = c("aut", "cre"),
                        email = "fvidoli@gmail.com"),
                 person(given = "Elisa",
                        family = "Fusco",
                        role = "aut"))
Maintainer: Francesco Vidoli <fvidoli@gmail.com>
Description: A collection of functions to calculate Composite Indicators methods, focusing, in particular, on the normalisation and weighting-aggregation steps, as described in OECD Handbook on constructing composite indicators: methodology and user guide, 2008, 'Vidoli' and 'Fusco' and 'Mazziotta' <doi:10.1007/s11205-014-0710-y>, 'Mazziotta' and 'Pareto' (2016) <doi:10.1007/s11205-015-0998-2>, 'Van Puyenbroeck and 'Rogge' <doi:10.1016/j.ejor.2016.07.038> and other authors.
Depends: R (>= 3.5.0), Benchmarking, psych, boot, lpSolve, spdep
Imports: Hmisc, MASS, GPArotation, nonparaeff, smaa, np, FactoMineR,
        GWmodel, sp, Rcompadre
License: GPL-3
Suggests: R.rsp
VignetteBuilder: R.rsp
NeedsCompilation: no
Packaged: 2026-07-10 08:28:20 UTC; Fra
Repository: CRAN
Date/Publication: 2026-07-10 08:50:26 UTC
Author: Francesco Vidoli [aut, cre],
  Elisa Fusco [aut]
