exportPattern("^[[:alpha:]]+")

#import(Benchmarking)
importFrom(Benchmarking, dea)
importFrom(Benchmarking, mea)
#import(psych)
importFrom(psych, principal)
#importFrom(psych, geometric.mean)
#import(boot)
importFrom(boot, boot)
importFrom(boot, boot.ci)

importFrom(nonparaeff, orderm)
importFrom(nonparaeff, ar.dual.dea)
importFrom(Rcompadre,mat_mean)

import(Hmisc)
import(MASS)
import(GPArotation)
import(lpSolve)

import(spdep)

importFrom("stats", "var")
importFrom("stats", "qt")
importFrom("stats", "sd")
importFrom("stats", "median")
importFrom("stats", "runif")
importFrom("stats", "biplot")

importFrom("FactoMineR", "FAMD")

importFrom("utils", "read.table")
importFrom("np", "npcdensbw")
importFrom("np", "npksum")

importFrom("smaa", "smaa.values")
importFrom("smaa", "smaa.ranks")

importFrom("GWmodel", "gw.dist")
importFrom("GWmodel", "gw.weight")
importFrom("GWmodel", "bw.gwss.average")

importFrom("sp", "SpatialPointsDataFrame")
importFrom("stats", "quantile")



